package middleware

import (
	"taskcenter/util"

	"github.com/gin-gonic/gin"
	log "github.com/sirupsen/logrus"
)

func JWTMiddleware(secret string, needAdmin bool) gin.HandlerFunc {
	return func(c *gin.Context) {
		tokenString := c.GetHeader("Authorization")
		if tokenString == "" || len(tokenString) < 7 {
			c.JSON(200, gin.H{
				"code": 1,
				"msg":  "invalid token",
				"data": "",
			})
			c.Abort()
			return
		}

		ok, expired, uid, role := util.ParseJWT(secret, tokenString[7:])
		if !ok {
			c.JSON(200, gin.H{
				"code": 1,
				"msg":  "invalid token",
				"data": "",
			})
			c.Abort()
			return
		}

		if expired {
			c.JSON(200, gin.H{
				"code": 1,
				"msg":  "token expired",
				"data": "",
			})
			c.Abort()
			return
		}

		if needAdmin && role != "admin" {
			c.JSON(200, gin.H{
				"code": 1,
				"msg":  "permission denied",
				"data": "",
			})
			c.Abort()
			return
		}

		log.WithField("userId", uid).Debug("jwt uid")
		c.Set("userId", uid)
		c.Next()
	}
}
